#!/usr/bin/env python
# -*- coding:utf-8 -*-
# Author: wxnacy <wxnacy@gmail.com>
# Description: model 常量


import os

DB_PATH = os.path.expanduser('~/multitasker.db?check_same_thread=false')
